Refactored the forwarding module to use the new packet API.

It now uses PacketService for both receiving packet-ins and sending
packet-outs, so there is now no dependency on FloodlightProvider or
FlowPusher.

Fixed a bug where the packet module wasn't sending packet-outs correctly.

Change-Id: If738797cdcebabfed975875daf4b40df99226585
diff --git a/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java b/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java
index 8fe8efe..d95ddf2 100644
--- a/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java
+++ b/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java
@@ -3,6 +3,8 @@
 import java.io.Serializable;
 import java.util.Arrays;
 
+import net.onrc.onos.core.topology.NetworkGraph;
+
 import com.google.common.collect.Multimap;
 
 /**
@@ -51,11 +53,12 @@
      * calculate that list, given the list of edge ports controlled by this
      * instance.
      *
      * @param localSwitches the map of locally-controlled edge ports
      * @return a multimap of ports that the packet should be sent out,
      * in the form
      * {@code {dpid1 => {portnum1, portnum2, ...}, dpid2 => {portnum1}, ...}}
      */
     public abstract Multimap<Long, Short> calculateOutPorts(
-            Multimap<Long, Short> localEdgePorts);
+            Multimap<Long, Short> localPorts, NetworkGraph networkGraph);
 }
@@ -51,11 +53,12 @@
      * instance.
      *
-     * @param localSwitches the map of locally-controlled edge ports
+     * @param localPorts the map of locally-controlled ports
+     * @param networkGraph an instance of the global network graph
      * @return a multimap of ports that the packet should be sent out,
      * in the form